@@ -33,7 +33,6 @@ from io.output import MirrorOutput
 class Image(Container):
   "An embedded image"
 
-  start = '\\begin_inset Graphics'
   ending = '\\end_inset'
 
   converter = True
@@ -133,5 +132,3 @@ class ImageOutput(object):
     html.append('/>\n')
     return html
 
-ContainerFactory.types.append(Image)
-
