@@ -32,7 +32,6 @@ from gen.container import *
 class Layout(Container):
   "A layout (block of text) inside a lyx file"
 
-  start = '\\begin_layout'
   ending = '\\end_layout'
 
   typetags = {
@@ -62,7 +61,6 @@ class Layout(Container):
 class Title(Layout):
   "The title of the whole document"
 
-  start = '\\begin_layout Title'
   ending = '\\end_layout'
 
   def process(self):
@@ -75,7 +73,6 @@ class Title(Layout):
 class Author(Layout):
   "The document author"
 
-  start = '\\begin_layout Author'
   ending = '\\end_layout'
 
   def process(self):
@@ -85,6 +82,18 @@ class Author(Layout):
     FooterOutput.author = string.contents[0]
     Trace.debug('Author: ' + FooterOutput.author)
 
+class Abstract(Layout):
+  "A paper abstract"
+
+  ending = '\\end_layout'
+
+  def process(self):
+    self.type = 'abstract'
+    self.output.tag = 'div class="abstract"'
+    message = TranslationConfig.constants['abstract']
+    tagged = TaggedText().constant(message, 'p class="abstract-message"', True)
+    self.contents.insert(0, tagged)
+
 class FirstWorder(Layout):
   "A layout where the first word is extracted"
 
@@ -137,7 +146,6 @@ class FirstWorder(Layout):
 class Description(FirstWorder):
   "A description layout"
 
-  start = '\\begin_layout Description'
   ending = '\\end_layout'
 
   def process(self):
@@ -154,7 +162,6 @@ class Description(FirstWorder):
 class List(FirstWorder):
   "A list layout"
 
-  start = '\\begin_layout List'
   ending = '\\end_layout'
 
   def process(self):
@@ -167,7 +174,3 @@ class List(FirstWorder):
     tag = 'span class="List-entry"'
     self.contents.insert(0, TaggedText().complete(firstword, tag))
 
-ContainerFactory.types += [
-    Layout, Title, Author, Description, List
-    ]
-
