@@ -32,7 +32,6 @@ from parse.formulaparse import *
 class Formula(Container):
   "A LaTeX formula"
 
-  start = '\\begin_inset Formula'
   ending = '\\end_inset'
 
   def __init__(self):
@@ -236,5 +235,3 @@ class WholeFormula(FormulaBit):
       return True
     return False
 
-ContainerFactory.types.append(Formula)
-
